import React, { Suspense } from 'react';
import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';
import { HelmetProvider } from 'react-helmet-async';
import Header from './components/layout/Header';
import Footer from './components/layout/Footer';
import ScrollToTop from './components/layout/ScrollToTop';

// Eagerly load frequently accessed pages
import HomePage from './pages/HomePage';
import JobsPage from './pages/JobsPage';
import JobDetailPage from './pages/JobDetailPage';

// Lazy load less frequently accessed pages
const PostJobPage = React.lazy(() => import('./pages/PostJobPage'));
const PaymentSuccessPage = React.lazy(() => import('./pages/PaymentSuccessPage'));
const AdminCsvUploadPage = React.lazy(() => import('./pages/AdminCsvUploadPage'));
const AdminJobsPage = React.lazy(() => import('./pages/AdminJobsPage'));
const LoginPage = React.lazy(() => import('./pages/LoginPage'));
const AdminBlogPage = React.lazy(() => import('./pages/AdminBlogPage'));
const BlogPostEditorPage = React.lazy(() => import('./pages/BlogPostEditorPage'));
const BlogPage = React.lazy(() => import('./pages/BlogPage'));
const BlogPostPage = React.lazy(() => import('./pages/BlogPostPage'));
const AdminPagesPage = React.lazy(() => import('./pages/AdminPagesPage'));
const StaticPageEditorPage = React.lazy(() => import('./pages/StaticPageEditorPage'));
const StaticPage = React.lazy(() => import('./pages/StaticPage'));

// Loading fallback component
const LoadingFallback = () => (
  <div className="min-h-[50vh] flex items-center justify-center">
    <div className="animate-spin rounded-full h-8 w-8 border-2 border-primary-600 border-t-transparent"></div>
  </div>
);

function App() {
  return (
    <HelmetProvider>
      <Router>
        <ScrollToTop />
        <div className="flex flex-col min-h-screen">
          <Header />
          <div className="flex-grow">
            <Routes>
              {/* Main routes - eagerly loaded */}
              <Route path="/" element={<HomePage />} />
              <Route path="/jobs" element={<JobsPage />} />
              <Route path="/job/:id" element={<JobDetailPage />} />

              {/* Lazily loaded routes */}
              <Route path="/post-a-job" element={
                <Suspense fallback={<LoadingFallback />}>
                  <PostJobPage />
                </Suspense>
              } />
              <Route path="/payment-success" element={
                <Suspense fallback={<LoadingFallback />}>
                  <PaymentSuccessPage />
                </Suspense>
              } />
              <Route path="/blog" element={
                <Suspense fallback={<LoadingFallback />}>
                  <BlogPage />
                </Suspense>
              } />
              <Route path="/blog/:slug" element={
                <Suspense fallback={<LoadingFallback />}>
                  <BlogPostPage />
                </Suspense>
              } />
              <Route path="/login" element={
                <Suspense fallback={<LoadingFallback />}>
                  <LoginPage />
                </Suspense>
              } />

              {/* Admin routes */}
              <Route path="/admin" element={<Navigate to="/admin/jobs" replace />} />
              <Route path="/admin/jobs" element={
                <Suspense fallback={<LoadingFallback />}>
                  <AdminJobsPage />
                </Suspense>
              } />
              <Route path="/admin/upload-csv" element={
                <Suspense fallback={<LoadingFallback />}>
                  <AdminCsvUploadPage />
                </Suspense>
              } />
              <Route path="/admin/blog" element={
                <Suspense fallback={<LoadingFallback />}>
                  <AdminBlogPage />
                </Suspense>
              } />
              <Route path="/admin/blog/new" element={
                <Suspense fallback={<LoadingFallback />}>
                  <BlogPostEditorPage />
                </Suspense>
              } />
              <Route path="/admin/blog/edit/:id" element={
                <Suspense fallback={<LoadingFallback />}>
                  <BlogPostEditorPage />
                </Suspense>
              } />
              <Route path="/admin/pages" element={
                <Suspense fallback={<LoadingFallback />}>
                  <AdminPagesPage />
                </Suspense>
              } />
              <Route path="/admin/pages/edit/:slug" element={
                <Suspense fallback={<LoadingFallback />}>
                  <StaticPageEditorPage />
                </Suspense>
              } />

              {/* Static pages - must be last */}
              <Route path="/:slug" element={
                <Suspense fallback={<LoadingFallback />}>
                  <StaticPage />
                </Suspense>
              } />
            </Routes>
          </div>
          <Footer />
        </div>
      </Router>
    </HelmetProvider>
  );
}

export default App;